@@ -35,9 +35,11 @@ private:
 	cFritzEventHandler *event;
 	static bool open;
 	std::vector<std::string> lines;
+	time_t lastUpdate;
 public:
 	cNotifyOsd(cFritzEventHandler *event);
 	virtual ~cNotifyOsd();
+	bool GenerateOsdText();
 	virtual void Show(void);
 	virtual eOSState ProcessKey(eKeys Key);
 	static bool isOpen() { return open; }
